import { Component, ElementRef, EventEmitter, Input, NgModule, Output } from '@angular/core';
import { CommonModule } from '@angular/common';
var ngxEditorConfig = {
    editable: true,
    spellcheck: true,
    height: 'auto',
    minHeight: '0rem',
    translate: 'yes',
    placeholder: 'Enter text here...',
    toolbar: [
        ['bold', 'italic', 'underline', 'strikeThrough', 'superscript', 'subscript'],
        ['justifyLeft', 'justifyCenter', 'justifyRight', 'justifyFull', 'indent', 'outdent'],
        ['cut', 'copy', 'delete', 'removeFormat', 'undo', 'redo'],
        ['paragraph', 'blockquote', 'removeBlockquote', 'horizontalLine', 'orderedList', 'unorderedList']
    ]
};
/**
 * @param {?} value
 * @param {?} toolbar
 * @return {?}
 */
function canEnableToolbarOptions(value, toolbar) {
    if (value) {
        if (toolbar['length'] === 0) {
            return true;
        }
        else {
            return toolbar.find(function (array) {
                return array.includes(value);
            });
        }
    }
    else {
        return false;
    }
}
var NgxEditorComponent = /** @class */ (function () {
    /**
     * @param {?} element
     */
    function NgxEditorComponent(element) {
        this.element = element;
        this.htmlChange = new EventEmitter();
    }
    Object.defineProperty(NgxEditorComponent.prototype, "config", {
        /**
         * @return {?}
         */
        get: function () {
            return this._config || ngxEditorConfig;
        },
        /**
         * @param {?} value
         * @return {?}
         */
        set: function (value) {
            for (var /** @type {?} */ i in ngxEditorConfig) {
                if (i) {
                    if (this[i]) {
                        value[i] = this[i];
                    }
                    if (!value.hasOwnProperty(i)) {
                        value[i] = ngxEditorConfig[i];
                    }
                }
            }
            this._config = value;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(NgxEditorComponent.prototype, "html", {
        /**
         * @return {?}
         */
        get: function () {
            return this._html;
        },
        /**
         * @param {?} value
         * @return {?}
         */
        set: function (value) {
            this._html = value;
        },
        enumerable: true,
        configurable: true
    });
    /**
     * @param {?} value
     * @return {?}
     */
    NgxEditorComponent.prototype.htmlContentChange = function (value) {
        if (value === '<br>') {
            this.htmlChange.emit('');
        }
        else {
            this.htmlChange.emit(value);
        }
    };
    /**
     * @param {?} commandName
     * @return {?}
     */
    NgxEditorComponent.prototype.executeCommand = function (commandName) {
        var /** @type {?} */ isExecuted = document.execCommand(commandName, false, null);
    };
    /**
     * @return {?}
     */
    NgxEditorComponent.prototype.blockQuote = function () {
        document.execCommand('formatBlock', false, '<blockquote>');
    };
    /**
     * @return {?}
     */
    NgxEditorComponent.prototype.removeQuote = function () {
        document.execCommand('formatBlock', false, 'div');
    };
    /**
     * @param {?} value
     * @return {?}
     */
    NgxEditorComponent.prototype.canEnableToolbarOptions = function (value) {
        return canEnableToolbarOptions(value, this.config['toolbar']);
    };
    /**
     * @return {?}
     */
    NgxEditorComponent.prototype.ngOnInit = function () {
        this.element.nativeElement.getElementsByClassName('textarea')[0].innerHTML = this.html || '';
    };
    return NgxEditorComponent;
}());
NgxEditorComponent.decorators = [
    { type: Component, args: [{
                selector: 'app-ngx-editor',
                template: "\n    <div class=\"ngx-editor\" id=\"ngxEditor\">\n      <div class=\"toolbar\">\n        <div class=\"set\">\n          <button *ngIf=\"canEnableToolbarOptions('bold')\" (click)=\"executeCommand('bold')\" title=\"Bold\"><i class=\"fa fa-bold\" aria-hidden=\"true\"></i></button>\n          <button *ngIf=\"canEnableToolbarOptions('italic')\" (click)=\"executeCommand('italic')\" title=\"Italic\"><i class=\"fa fa-italic\" aria-hidden=\"true\"></i></button>\n          <button *ngIf=\"canEnableToolbarOptions('underline')\" (click)=\"executeCommand('underline')\" title=\"Underline\"><i class=\"fa fa-underline\" aria-hidden=\"true\"></i></button>\n          <button *ngIf=\"canEnableToolbarOptions('strikeThrough')\" (click)=\"executeCommand('strikeThrough')\" title=\"Strikethrough\"><i class=\"fa fa-strikethrough\" aria-hidden=\"true\"></i></button>\n          <button *ngIf=\"canEnableToolbarOptions('superscript')\" (click)=\"executeCommand('superscript')\" title=\"Superscript\"><i class=\"fa fa-superscript\" aria-hidden=\"true\"></i></button>\n          <button *ngIf=\"canEnableToolbarOptions('subscript')\" (click)=\"executeCommand('subscript')\" title=\"Subscript\"><i class=\"fa fa-subscript\" aria-hidden=\"true\"></i></button>\n        </div>\n        <div class=\"set\">\n          <button *ngIf=\"canEnableToolbarOptions('justifyLeft')\" (click)=\"executeCommand('justifyLeft')\" title=\"Justify Left\"><i class=\"fa fa-align-left\" aria-hidden=\"true\"></i></button>\n          <button *ngIf=\"canEnableToolbarOptions('justifyCenter')\" (click)=\"executeCommand('justifyCenter')\" title=\"Justify Center\"><i class=\"fa fa-align-center\" aria-hidden=\"true\"></i></button>\n          <button *ngIf=\"canEnableToolbarOptions('justifyRight')\" (click)=\"executeCommand('justifyRight')\" title=\"Justify Right\"><i class=\"fa fa-align-right\" aria-hidden=\"true\"></i></button>\n          <button *ngIf=\"canEnableToolbarOptions('justifyFull')\" (click)=\"executeCommand('justifyFull')\" title=\"Justify\"><i class=\"fa fa-align-justify\" aria-hidden=\"true\"></i></button>\n          <button *ngIf=\"canEnableToolbarOptions('indent')\" (click)=\"executeCommand('indent')\" title=\"Indent\"><i class=\"fa fa-indent\" aria-hidden=\"true\"></i></button>\n          <button *ngIf=\"canEnableToolbarOptions('outdent')\" (click)=\"executeCommand('outdent')\" title=\"Outdent\"><i class=\"fa fa-outdent\" aria-hidden=\"true\"></i></button>\n        </div>\n        <div class=\"set\">\n          <button *ngIf=\"canEnableToolbarOptions('cut')\" (click)=\"executeCommand('cut')\" title=\"Cut\"><i class=\"fa fa-scissors\" aria-hidden=\"true\"></i></button>\n          <button *ngIf=\"canEnableToolbarOptions('copy')\" (click)=\"executeCommand('copy')\" title=\"Copy\"><i class=\"fa fa-files-o\" aria-hidden=\"true\"></i></button>\n          <button *ngIf=\"canEnableToolbarOptions('delete')\" (click)=\"executeCommand('delete')\" title=\"Delete\"><i class=\"fa fa-trash\" aria-hidden=\"true\"></i></button>\n          <button *ngIf=\"canEnableToolbarOptions('removeFormat')\" (click)=\"executeCommand('removeFormat')\" title=\"Clear Formatting\"><i class=\"fa fa-eraser\" aria-hidden=\"true\"></i></button>\n          <button *ngIf=\"canEnableToolbarOptions('undo')\" (click)=\"executeCommand('undo')\" title=\"Undo\"><i class=\"fa fa-undo\" aria-hidden=\"true\"></i></button>\n          <button *ngIf=\"canEnableToolbarOptions('redo')\" (click)=\"executeCommand('redo')\" title=\"Redo\"><i class=\"fa fa-repeat\" aria-hidden=\"true\"></i></button>\n        </div>\n        <div class=\"set\">\n          <button *ngIf=\"canEnableToolbarOptions('paragraph')\" (click)=\"executeCommand('insertParagraph')\" title=\"Paragraph\"><i class=\"fa fa-paragraph\" aria-hidden=\"true\"></i></button>\n          <button *ngIf=\"canEnableToolbarOptions('blockquote')\" (click)=\"blockQuote()\" title=\"Blockquote\"><i class=\"fa fa-quote-left\" aria-hidden=\"true\"></i></button>\n          <button *ngIf=\"canEnableToolbarOptions('removeBlockquote')\" (click)=\"removeQuote()\" title=\"Remove Blockquote\"><i class=\"fa fa-quote-right\" aria-hidden=\"true\"></i></button>\n          <button *ngIf=\"canEnableToolbarOptions('horizontalLine')\" (click)=\"executeCommand('insertHorizontalRule')\" title=\"Horizontal Line\"><i class=\"fa fa-minus\" aria-hidden=\"true\"></i></button>\n          <button *ngIf=\"canEnableToolbarOptions('orderedList')\" (click)=\"executeCommand('insertUnorderedList')\" title=\"Unodered List\"><i class=\"fa fa-list-ul\" aria-hidden=\"true\"></i></button>\n          <button *ngIf=\"canEnableToolbarOptions('unorderedList')\" (click)=\"executeCommand('insertOrderedList')\" title=\"Ordered List\"><i class=\"fa fa-list-ol\" aria-hidden=\"true\"></i></button>\n        </div>\n      </div>\n      <div class=\"textarea\" [attr.contenteditable]=\"config['editable']\" [attr.placeholder]=\"config['placeholder']\" (input)=\"html = $event.target.innerHTML; htmlContentChange($event.target.innerHTML)\"\n        [attr.translate]=\"config['translate']\" [attr.spellcheck]=\"config['spellcheck']\" [style.height]=\"config['height']\" [style.minHeight]=\"minHeight || config['minHeight']\"></div>\n    </div>\n  ",
                styles: ["\n    /*\n     * editor styles\n     */\n    .ngx-editor {\n      position: relative; }\n      .ngx-editor ::ng-deep [contenteditable=true]:empty:before {\n        content: attr(placeholder);\n        display: block; }\n      .ngx-editor .toolbar {\n        background-color: #f5f5f5;\n        border-bottom: 1px solid #ddd;\n        font-size: 0.8rem;\n        padding: 0.2rem;\n        border: 1px solid #ddd; }\n        .ngx-editor .toolbar .set {\n          display: inline-block;\n          border: 1px solid #ddd;\n          border-radius: 5px;\n          background-color: white; }\n          .ngx-editor .toolbar .set button {\n            background-color: #f5f5f5;\n            background-color: transparent;\n            border: 0;\n            padding: 0.4rem;\n            min-width: 2.5rem;\n            float: left;\n            border-right: 1px solid #ddd; }\n            .ngx-editor .toolbar .set button:hover {\n              cursor: pointer;\n              background-color: #e3e3e3;\n              -webkit-transition: 0.5s ease;\n              transition: 0.5s ease; }\n            .ngx-editor .toolbar .set button:focus, .ngx-editor .toolbar .set button.focus {\n              outline: 0; }\n            .ngx-editor .toolbar .set button:last-child {\n              border-right: transparent; }\n      .ngx-editor .textarea {\n        min-height: 5rem;\n        padding: 0.5rem 0.8rem 1rem 0.8rem;\n        border: 1px solid #ddd;\n        border-top: transparent;\n        resize: vertical;\n        overflow: auto;\n        background-color: #fff; }\n        .ngx-editor .textarea:focus, .ngx-editor .textarea.focus {\n          outline: 0; }\n        .ngx-editor .textarea ::ng-deep blockquote {\n          margin-left: 1rem;\n          border-left: 0.2em solid #dfe2e5;\n          padding-left: 0.5rem; }\n        .ngx-editor .textarea .grabber {\n          content: '';\n          position: absolute;\n          bottom: 0;\n          margin-left: -0.8rem;\n          cursor: s-resize;\n          height: 9px;\n          width: 100%;\n          border-top: 1px solid #f1f1f1;\n          overflow: hidden;\n          background-color: #eff0f1;\n          background-image: url(\"../../assets/grabber/grabber.png\");\n          background-image: url(\"../../assets/grabber/grabber.svg\"), none;\n          background-size: initial;\n          background-repeat: no-repeat;\n          background-position: center; }\n\n    .hide {\n      display: none !important; }\n  "]
            },] },
];
/**
 * @nocollapse
 */
NgxEditorComponent.ctorParameters = function () { return [
    { type: ElementRef, },
]; };
NgxEditorComponent.propDecorators = {
    'htmlChange': [{ type: Output },],
    'editable': [{ type: Input },],
    'spellcheck': [{ type: Input },],
    'placeholder': [{ type: Input },],
    'translate': [{ type: Input },],
    'height': [{ type: Input },],
    'minHeight': [{ type: Input },],
    'toolbar': [{ type: Input },],
    'config': [{ type: Input },],
    'html': [{ type: Input },],
};
var NgxEditorModule = /** @class */ (function () {
    function NgxEditorModule() {
    }
    return NgxEditorModule;
}());
NgxEditorModule.decorators = [
    { type: NgModule, args: [{
                imports: [
                    CommonModule
                ],
                declarations: [
                    NgxEditorComponent
                ],
                exports: [
                    NgxEditorComponent
                ]
            },] },
];
/**
 * @nocollapse
 */
NgxEditorModule.ctorParameters = function () { return []; };
/**
 * Generated bundle index. Do not edit.
 */
export { NgxEditorModule, NgxEditorComponent as ɵa };
//# sourceMappingURL=ngx-editor.es5.js.map
