import { Component, ElementRef, EventEmitter, Input, NgModule, Output } from '@angular/core';
import { CommonModule } from '@angular/common';

const ngxEditorConfig = {
    editable: true,
    spellcheck: true,
    height: 'auto',
    minHeight: '0rem',
    translate: 'yes',
    placeholder: 'Enter text here...',
    toolbar: [
        ['bold', 'italic', 'underline', 'strikeThrough', 'superscript', 'subscript'],
        ['justifyLeft', 'justifyCenter', 'justifyRight', 'justifyFull', 'indent', 'outdent'],
        ['cut', 'copy', 'delete', 'removeFormat', 'undo', 'redo'],
        ['paragraph', 'blockquote', 'removeBlockquote', 'horizontalLine', 'orderedList', 'unorderedList']
    ]
};

/**
 * @param {?} value
 * @param {?} toolbar
 * @return {?}
 */
function canEnableToolbarOptions(value, toolbar) {
    if (value) {
        if (toolbar['length'] === 0) {
            return true;
        }
        else {
            return toolbar.find(array => {
                return array.includes(value);
            });
        }
    }
    else {
        return false;
    }
}

class NgxEditorComponent {
    /**
     * @param {?} element
     */
    constructor(element) {
        this.element = element;
        this.htmlChange = new EventEmitter();
    }
    /**
     * @param {?} value
     * @return {?}
     */
    set config(value) {
        for (const /** @type {?} */ i in ngxEditorConfig) {
            if (i) {
                if (this[i]) {
                    value[i] = this[i];
                }
                if (!value.hasOwnProperty(i)) {
                    value[i] = ngxEditorConfig[i];
                }
            }
        }
        this._config = value;
    }
    /**
     * @return {?}
     */
    get config() {
        return this._config || ngxEditorConfig;
    }
    /**
     * @param {?} value
     * @return {?}
     */
    set html(value) {
        this._html = value;
    }
    /**
     * @return {?}
     */
    get html() {
        return this._html;
    }
    /**
     * @param {?} value
     * @return {?}
     */
    htmlContentChange(value) {
        if (value === '<br>') {
            this.htmlChange.emit('');
        }
        else {
            this.htmlChange.emit(value);
        }
    }
    /**
     * @param {?} commandName
     * @return {?}
     */
    executeCommand(commandName) {
        const /** @type {?} */ isExecuted = document.execCommand(commandName, false, null);
    }
    /**
     * @return {?}
     */
    blockQuote() {
        document.execCommand('formatBlock', false, '<blockquote>');
    }
    /**
     * @return {?}
     */
    removeQuote() {
        document.execCommand('formatBlock', false, 'div');
    }
    /**
     * @param {?} value
     * @return {?}
     */
    canEnableToolbarOptions(value) {
        return canEnableToolbarOptions(value, this.config['toolbar']);
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        this.element.nativeElement.getElementsByClassName('textarea')[0].innerHTML = this.html || '';
    }
}
NgxEditorComponent.decorators = [
    { type: Component, args: [{
                selector: 'app-ngx-editor',
                template: `
    <div class="ngx-editor" id="ngxEditor">
      <div class="toolbar">
        <div class="set">
          <button *ngIf="canEnableToolbarOptions('bold')" (click)="executeCommand('bold')" title="Bold"><i class="fa fa-bold" aria-hidden="true"></i></button>
          <button *ngIf="canEnableToolbarOptions('italic')" (click)="executeCommand('italic')" title="Italic"><i class="fa fa-italic" aria-hidden="true"></i></button>
          <button *ngIf="canEnableToolbarOptions('underline')" (click)="executeCommand('underline')" title="Underline"><i class="fa fa-underline" aria-hidden="true"></i></button>
          <button *ngIf="canEnableToolbarOptions('strikeThrough')" (click)="executeCommand('strikeThrough')" title="Strikethrough"><i class="fa fa-strikethrough" aria-hidden="true"></i></button>
          <button *ngIf="canEnableToolbarOptions('superscript')" (click)="executeCommand('superscript')" title="Superscript"><i class="fa fa-superscript" aria-hidden="true"></i></button>
          <button *ngIf="canEnableToolbarOptions('subscript')" (click)="executeCommand('subscript')" title="Subscript"><i class="fa fa-subscript" aria-hidden="true"></i></button>
        </div>
        <div class="set">
          <button *ngIf="canEnableToolbarOptions('justifyLeft')" (click)="executeCommand('justifyLeft')" title="Justify Left"><i class="fa fa-align-left" aria-hidden="true"></i></button>
          <button *ngIf="canEnableToolbarOptions('justifyCenter')" (click)="executeCommand('justifyCenter')" title="Justify Center"><i class="fa fa-align-center" aria-hidden="true"></i></button>
          <button *ngIf="canEnableToolbarOptions('justifyRight')" (click)="executeCommand('justifyRight')" title="Justify Right"><i class="fa fa-align-right" aria-hidden="true"></i></button>
          <button *ngIf="canEnableToolbarOptions('justifyFull')" (click)="executeCommand('justifyFull')" title="Justify"><i class="fa fa-align-justify" aria-hidden="true"></i></button>
          <button *ngIf="canEnableToolbarOptions('indent')" (click)="executeCommand('indent')" title="Indent"><i class="fa fa-indent" aria-hidden="true"></i></button>
          <button *ngIf="canEnableToolbarOptions('outdent')" (click)="executeCommand('outdent')" title="Outdent"><i class="fa fa-outdent" aria-hidden="true"></i></button>
        </div>
        <div class="set">
          <button *ngIf="canEnableToolbarOptions('cut')" (click)="executeCommand('cut')" title="Cut"><i class="fa fa-scissors" aria-hidden="true"></i></button>
          <button *ngIf="canEnableToolbarOptions('copy')" (click)="executeCommand('copy')" title="Copy"><i class="fa fa-files-o" aria-hidden="true"></i></button>
          <button *ngIf="canEnableToolbarOptions('delete')" (click)="executeCommand('delete')" title="Delete"><i class="fa fa-trash" aria-hidden="true"></i></button>
          <button *ngIf="canEnableToolbarOptions('removeFormat')" (click)="executeCommand('removeFormat')" title="Clear Formatting"><i class="fa fa-eraser" aria-hidden="true"></i></button>
          <button *ngIf="canEnableToolbarOptions('undo')" (click)="executeCommand('undo')" title="Undo"><i class="fa fa-undo" aria-hidden="true"></i></button>
          <button *ngIf="canEnableToolbarOptions('redo')" (click)="executeCommand('redo')" title="Redo"><i class="fa fa-repeat" aria-hidden="true"></i></button>
        </div>
        <div class="set">
          <button *ngIf="canEnableToolbarOptions('paragraph')" (click)="executeCommand('insertParagraph')" title="Paragraph"><i class="fa fa-paragraph" aria-hidden="true"></i></button>
          <button *ngIf="canEnableToolbarOptions('blockquote')" (click)="blockQuote()" title="Blockquote"><i class="fa fa-quote-left" aria-hidden="true"></i></button>
          <button *ngIf="canEnableToolbarOptions('removeBlockquote')" (click)="removeQuote()" title="Remove Blockquote"><i class="fa fa-quote-right" aria-hidden="true"></i></button>
          <button *ngIf="canEnableToolbarOptions('horizontalLine')" (click)="executeCommand('insertHorizontalRule')" title="Horizontal Line"><i class="fa fa-minus" aria-hidden="true"></i></button>
          <button *ngIf="canEnableToolbarOptions('orderedList')" (click)="executeCommand('insertUnorderedList')" title="Unodered List"><i class="fa fa-list-ul" aria-hidden="true"></i></button>
          <button *ngIf="canEnableToolbarOptions('unorderedList')" (click)="executeCommand('insertOrderedList')" title="Ordered List"><i class="fa fa-list-ol" aria-hidden="true"></i></button>
        </div>
      </div>
      <div class="textarea" [attr.contenteditable]="config['editable']" [attr.placeholder]="config['placeholder']" (input)="html = $event.target.innerHTML; htmlContentChange($event.target.innerHTML)"
        [attr.translate]="config['translate']" [attr.spellcheck]="config['spellcheck']" [style.height]="config['height']" [style.minHeight]="minHeight || config['minHeight']"></div>
    </div>
  `,
                styles: [`
    /*
     * editor styles
     */
    .ngx-editor {
      position: relative; }
      .ngx-editor ::ng-deep [contenteditable=true]:empty:before {
        content: attr(placeholder);
        display: block; }
      .ngx-editor .toolbar {
        background-color: #f5f5f5;
        border-bottom: 1px solid #ddd;
        font-size: 0.8rem;
        padding: 0.2rem;
        border: 1px solid #ddd; }
        .ngx-editor .toolbar .set {
          display: inline-block;
          border: 1px solid #ddd;
          border-radius: 5px;
          background-color: white; }
          .ngx-editor .toolbar .set button {
            background-color: #f5f5f5;
            background-color: transparent;
            border: 0;
            padding: 0.4rem;
            min-width: 2.5rem;
            float: left;
            border-right: 1px solid #ddd; }
            .ngx-editor .toolbar .set button:hover {
              cursor: pointer;
              background-color: #e3e3e3;
              -webkit-transition: 0.5s ease;
              transition: 0.5s ease; }
            .ngx-editor .toolbar .set button:focus, .ngx-editor .toolbar .set button.focus {
              outline: 0; }
            .ngx-editor .toolbar .set button:last-child {
              border-right: transparent; }
      .ngx-editor .textarea {
        min-height: 5rem;
        padding: 0.5rem 0.8rem 1rem 0.8rem;
        border: 1px solid #ddd;
        border-top: transparent;
        resize: vertical;
        overflow: auto;
        background-color: #fff; }
        .ngx-editor .textarea:focus, .ngx-editor .textarea.focus {
          outline: 0; }
        .ngx-editor .textarea ::ng-deep blockquote {
          margin-left: 1rem;
          border-left: 0.2em solid #dfe2e5;
          padding-left: 0.5rem; }
        .ngx-editor .textarea .grabber {
          content: '';
          position: absolute;
          bottom: 0;
          margin-left: -0.8rem;
          cursor: s-resize;
          height: 9px;
          width: 100%;
          border-top: 1px solid #f1f1f1;
          overflow: hidden;
          background-color: #eff0f1;
          background-image: url("../../assets/grabber/grabber.png");
          background-image: url("../../assets/grabber/grabber.svg"), none;
          background-size: initial;
          background-repeat: no-repeat;
          background-position: center; }

    .hide {
      display: none !important; }
  `]
            },] },
];
/**
 * @nocollapse
 */
NgxEditorComponent.ctorParameters = () => [
    { type: ElementRef, },
];
NgxEditorComponent.propDecorators = {
    'htmlChange': [{ type: Output },],
    'editable': [{ type: Input },],
    'spellcheck': [{ type: Input },],
    'placeholder': [{ type: Input },],
    'translate': [{ type: Input },],
    'height': [{ type: Input },],
    'minHeight': [{ type: Input },],
    'toolbar': [{ type: Input },],
    'config': [{ type: Input },],
    'html': [{ type: Input },],
};

class NgxEditorModule {
}
NgxEditorModule.decorators = [
    { type: NgModule, args: [{
                imports: [
                    CommonModule
                ],
                declarations: [
                    NgxEditorComponent
                ],
                exports: [
                    NgxEditorComponent
                ]
            },] },
];
/**
 * @nocollapse
 */
NgxEditorModule.ctorParameters = () => [];

/**
 * Generated bundle index. Do not edit.
 */

export { NgxEditorModule, NgxEditorComponent as ɵa };
//# sourceMappingURL=ngx-editor.js.map
